from distutils.core import setup

setup(
    name = 'tester_mine',
    version = '1.0.0',
    py_modules = ['nester_mine'],
    author = 'Neeta',
    author_email = 'neeta.kc104@gmail.com',
    description = 'module to print nested list'
)